@@ -4,7 +4,7 @@ package Mail::Builder;
 
 use Moose;
 
-our $VERSION = "2.06";
+our $VERSION = "2.07";
 our $AUTHORITY = 'cpan:MAROS';
 
 use Mail::Builder::TypeConstraints;
@@ -670,6 +670,14 @@ C<has_reply> and C<has_sender> methods.
 Values can be cleared with the C<clear_from>, C<clear_reply>,
 C<clear_reply> and C<clear_sender> methods.
 
+L<Email::Valid> options may be changed by setting the appropriate values
+in the %Mail::Builder::TypeConstraints::EMAILVALID hash.
+
+Eg. if you want to disable the check for valid TLDs you can set the 'tldcheck'
+option (without dashes 'tldcheck' and not '-tldcheck'):
+
+ $Mail::Builder::TypeConstraints{tldcheck} = 0;
+
 =head3 to, cc, bcc
 
  $obj->to(Mail::Builder::List)
@@ -725,7 +733,7 @@ manipulating the list of recipients. e.g.
 
 =head3 date
 
-e-mail date header. Accepts/returns a RFC2822 date. Also accepts a 
+e-mail date header. Accepts/returns a RFC2822 date string. Also accepts a 
 DateTime object or epoch integer. Will be autogenerated if not provided.
 C<clear_date> can be used to reset the date accessor.
 
@@ -739,6 +747,8 @@ methods can be used to check respectively clear the value.
 Message ID of the e-mail as a  L<Email::MessageID> object. Read only and 
 available only after the C<build_message> or C<stingify> methods have been 
 called. Each call to C<build_message> or C<stingify> changes the message ID.
+The C<has_messageid> and C<clear_messageid> methods can be used to check 
+respectively clear the value.
 
 =head3 organization
  
@@ -771,7 +781,7 @@ methods can be used to check or clear the value.
 
 This text will be autogenerated from htmltext if not provided by the user 
 and the C<autotext> option is not turned off. Simple formating (e.g. <strong>, 
-<em>) will be converted to pseudo formating.
+<em>, ...) will be converted to pseudo formating.
 
 If you want to disable the autogeneration of plaintext parts set the 
 L<autotext> accessor to a false value. However be aware that most anti-spam 
@@ -888,8 +898,7 @@ If you want to append an additional attachment to the list use
  $obj->image([
     HashRef | Mail::Builder::Image | PATH | Path::Class::File | FH | IO::File | ScalarRef
  ]);
- 
- 
+
 This accessor always returns a Mail::Builder::List object. If you supply
 a L<Mail::Builder::List> the list will be replaced.
 
