@@ -4,7 +4,7 @@ package Mail::Builder::Attachment;
 
 use Moose;
 with qw(Mail::Builder::Role::File);
-use Mail::Builder::Role::TypeConstraints;
+use Mail::Builder::TypeConstraints;
 
 use MIME::Types;
 use Carp;
@@ -204,7 +204,7 @@ the current filename will be used.
 
 =head3 mimetype
 
-Mime type of the attachment. Valid types are
+Mime type of the attachment.
 
 If not provided the mime type is determined by analyzing the filename 
 extension.
@@ -217,7 +217,7 @@ Attachment file. Can be a
 
 =item * Path (or a Path::Class::File object)
 
-=item * Filehandle (or a IO::File object)
+=item * Filehandle (or an IO::File object)
 
 =item * ScalarRef containing the attachment data
 
